% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calc_b.R
\encoding{UTF-8}
\name{calc_b}
\alias{calc_b}
\title{Calculate the metabolic scaling coefficient, b}
\usage{
calc_b(mass, MO2, method = "nls", plot = "linear", b0_start = 1)
}
\arguments{
\item{mass}{a vector of animal masses.}

\item{MO2}{a vector of metabolic rates.}

\item{method}{a string defining which method of calculating scaling coefficients to use. Default is "nls", which utilizes a nonlinear least squares regression. If this does not fit your data well, "lm" may also be used, which calculates a linear regression of log10(\code{MO2}) ~ log10(\code{mass}) with slope and intercept equivalent to \code{b} and 10^\code{b0}, respectively.}

\item{plot}{a string defining what kind of plot to display. "linear" for linear axes, "log" for log10-scale axes, and "none" for no plot. Default is "linear".}

\item{b0_start}{a single numeric value as the starting point for \code{b0} value determination using the "nls" method. The default is \code{1} and should work for most situations, but if the "nls" method is not working and you don't want to use the "lm" method, changing the starting \code{b0} value may help. Ignored when method = "lm".}
}
\value{
Returns a list of 1) the \code{b} value, 2) a vector of \code{b0} values corresponding to the input \code{MO2} values, and 3) an average \code{b0} that can be used for summarizing the relationship with an equation.
}
\description{
For most organisms, metabolic rate does not scale linearly, but rather according to a power function: \eqn{MO2 = b0 * M^b}. This function estimates the scaling coefficient, \code{b}, and normalization constant, \code{b0}, given MO2s from different sized individuals.
}
\details{
\deqn{MO2 = b0 * M^b}
where \code{b0} is species-specific normalization constant, \code{M} is mass and \code{b} is the scaling coefficient.
}
\examples{
# Simple example
mass <- c(1, 10, 100, 1000, 40, 4, 400, 60, 2, 742, 266, 983) # made up values
MO2 <- mass ^ 0.65 + rnorm(n = length(mass)) # make up some data
calc_b(mass = mass, MO2 = MO2)

# How about some mass-specific MO2s?
msMO2 <- mass ^ -0.25 + rnorm(n = length(mass), sd = 0.05)
calc_b(mass = mass, MO2 = msMO2)
calc_b(mass = mass, MO2 = msMO2, plot = "log")

}
\seealso{
\code{\link{scale_MO2}}, \code{\link{calc_MO2}}
}
\author{
Matthew A. Birk, \email{matthewabirk@gmail.com}
}
